@@ -8,9 +8,9 @@
 """
 
 import os
+
 import fabric
 import fabtools
-
 from fabric.api import env
 
 
@@ -82,6 +82,10 @@ def build_env():
     env.lib_path = os.path.dirname(__file__)
     env.previous_settings_file = ""
 
+    if "socket_host" not in env:
+        env.socket_host = env.host
+
+
     if not "releases" in env:
         if fabtools.files.is_dir(env.remote_releases_path):
             env.releases = sorted(fabric.api.run('ls -x %(releases_path)s' %
