@@ -1,10 +1,14 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import copy
 from unittest import TestCase
+
 from fabric.api import env
-from mock import patch, call, Mock
-from pydiploy.require.releases_manager import set_current, setup, cleanup, deploy_code, rollback_code, symlink
+from mock import call, Mock, patch
+from pydiploy.require.releases_manager import (cleanup, deploy_code,
+                                               rollback_code, set_current,
+                                               setup, symlink)
 
 
 class ReleasesManagerCheck(TestCase):
@@ -14,6 +18,7 @@ class ReleasesManagerCheck(TestCase):
     """
 
     def setUp(self):
+        self.previous_env = copy.deepcopy(env)
         env.remote_current_release = "remote_current_release"
         env.remote_current_path = "remote_current_path"
         env.remote_project_dir = "remote_project_dir"
@@ -41,6 +46,7 @@ class ReleasesManagerCheck(TestCase):
 
     def tearDown(self):
         env.clear()
+        env.update(self.previous_env)
 
     @patch('fabric.api.sudo', return_value=Mock())
     def test_set_current(self, api_sudo):
