@@ -1,10 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import copy
 from unittest import TestCase
+
 from fabric.api import env
-from mock import patch, call, Mock
-from pydiploy.require.circus import circus_pkg, app_circus_conf, upstart, app_reload
+from mock import call, Mock, patch
+from pydiploy.require.circus import (app_circus_conf, app_reload, circus_pkg,
+                                     upstart)
 
 
 class CircusCheck(TestCase):
@@ -14,6 +17,7 @@ class CircusCheck(TestCase):
     """
 
     def setUp(self):
+        self.previous_env = copy.deepcopy(env)
         env.remote_home = 'remote_home'
         env.lib_path = 'lib_path'
         env.remote_owner = 'remote_owner'
@@ -22,6 +26,7 @@ class CircusCheck(TestCase):
 
     def tearDown(self):
         env.clear()
+        env.update(self.previous_env)
 
     @patch('fabtools.system.distrib_id', return_value='Ubuntu')
     @patch('fabtools.system.distrib_release', return_value='10.04')
