@@ -1,9 +1,11 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import copy
 from unittest import TestCase
+
 from fabric.api import env
-from mock import patch, call, Mock
+from mock import call, Mock, patch
 from pydiploy.require.git import archive
 
 
@@ -14,12 +16,14 @@ class GitCheck(TestCase):
     """
 
     def setUp(self):
+        self.previous_env = copy.deepcopy(env)
         self.filename = "myfile"
         self.remote = "remote"
         self.prefix = "prefix"
 
     def tearDown(self):
         env.clear()
+        env.update(self.previous_env)
 
     @patch('fabric.api.abort', return_value=Mock())
     @patch('fabric.api.lcd', return_value=Mock())
